summaryrefslogtreecommitdiff
path: root/lisp/progmodes/ebnf-iso.el
diff options
context:
space:
mode:
authorWerner LEMBERG <wl@gnu.org>2005-03-25 08:47:00 +0000
committerWerner LEMBERG <wl@gnu.org>2005-03-25 08:47:00 +0000
commiteac9c0efd68cdd7a65439bb3958da1db56391bc9 (patch)
tree4733654eeb256615e015effdfdcc9f013b633862 /lisp/progmodes/ebnf-iso.el
parent9d03424549b3ac88a3bb8881f0dec3cc3bce586e (diff)
downloademacs-eac9c0efd68cdd7a65439bb3958da1db56391bc9.tar.gz
* progmodes/ebnf-abn.el, progmodes/ebnf-bnf.el,
progmodes/ebnf-ebx.el, progmodes/ebnf-dtd.el, progmodes/ebnf-iso.el, progmodes/ebnf-yac.el, progmodes/ebnf2ps.el, progmodes/idlwave.el, progmodes/sh-script.el, progmodes/xscheme.el: Replace `illegal' with `invalid'.
Diffstat (limited to 'lisp/progmodes/ebnf-iso.el')
-rw-r--r--lisp/progmodes/ebnf-iso.el8
1 files changed, 4 insertions, 4 deletions
diff --git a/lisp/progmodes/ebnf-iso.el b/lisp/progmodes/ebnf-iso.el
index f36065bd558..ba28dfb5af9 100644
--- a/lisp/progmodes/ebnf-iso.el
+++ b/lisp/progmodes/ebnf-iso.el
@@ -1,6 +1,6 @@
;;; ebnf-iso.el --- parser for ISO EBNF
-;; Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004
+;; Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005
;; Free Software Foundation, Inc.
;; Author: Vinicius Jose Latorre <viniciusjl@ig.com.br>
@@ -112,7 +112,7 @@
;;
;; ISO EBNF accepts the characters given by <character> production above,
;; HORIZONTAL TAB (^I), VERTICAL TAB (^K), NEWLINE (^J or ^M) and FORM FEED
;; (^L), any other characters are illegal. But ebnf2ps accepts also the
;; european 8-bit accentuated characters (from \240 to \377) and underscore
;; (_).
;;
@@ -427,7 +427,7 @@ See documentation for variable `ebnf-iso-lex'."
'end-of-input)
;; error
((eq token 'error)
- (error "Illegal character"))
+ (error "Invalid character"))
;; integer
((eq token 'integer)
(setq ebnf-iso-lex (ebnf-buffer-substring "0-9"))
@@ -527,7 +527,7 @@ See documentation for variable `ebnf-iso-lex'."
(forward-char)
(setq pair (1+ pair))))
(t
- (error "Illegal character"))
+ (error "Invalid character"))
))))
@@ -112,7 +112,7 @@
;; ISO EBNF accepts the characters given by <character> production above,
;; HORIZONTAL TAB (^I), VERTICAL TAB (^K), NEWLINE (^J or ^M) and FORM FEED
-;; (^L), any other characters are illegal. But ebnf2ps accepts also the
+;; (^L), any other characters are invalid. But ebnf2ps accepts also the
;; european 8-bit accentuated characters (from \240 to \377) and underscore
;; (_).